# ------------------------------------------------------------------------------
# Django-fatpages - Flatpages that ate too much
# Copyright (c) 2008 Bruno Bord
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
# ------------------------------------------------------------------------------
from django.core import validators
from django.db import models
from django.utils.translation import gettext_lazy as _
from utils import import_markups

MARKUP_CHOICES = import_markups()

class FatPage(models.Model):
    """A flatpage that ate too much."""
    url = models.CharField(_('URL'), maxlength=100, validator_list=[validators.isAlphaNumericURL],
        help_text=_("Example: '/about/contact/'. Make sure to have leading and trailing slashes."))
    title = models.CharField(_('title'), maxlength=200)
    content = models.TextField(_('content'))
    markup = models.CharField(_('markup'), maxlength=10, choices=MARKUP_CHOICES, default='html')
    pub_date = models.DateTimeField(_('publication date'), auto_now=True)

    class Meta:
        verbose_name = _('fat page')
        verbose_name_plural = _('fat pages')
        ordering = ('url',)

    class Admin:
        search_fields = ('url', 'title')

    def __str__(self):
        return "%s -- %s" % (self.url, self.title)

    def get_absolute_url(self):
        if not self.url.endswith('/'):
            return self.url + "/"
        return self.url


class MenuItem(models.Model):
    """Simple menu management system"""
    label = models.CharField(_('label'), maxlength=50)
    url = models.CharField(_('URL'), maxlength=100, help_text=_('Make sure to have a leading slash - trailing slashes are not mandatory, but nicer for Django.'))
    order = models.PositiveIntegerField(_('order'))

    class Meta:
        verbose_name = _('menu item')
        verbose_name_plural = _('menu items')
        ordering = ('order', 'url')

    class Admin:
        list_display = ['label', 'url', 'order']

    def __str__(self):
        return "%s -- %s" % (self.url, self.label)

# EOF
